@@ -1,7 +1,8 @@
 #1/2/14  switched the n.iter loop to a mclapply loop to allow for multicore parallel processing
+#05/111/24  Added  suppressWarnings for the poly and tet options when running in parallel
 
 "fa.parallel" <-
-function(x,n.obs=NULL,fm="minres",fa="both",nfactors=1,main="Parallel Analysis Scree Plots",n.iter=20,error.bars=FALSE,se.bars=FALSE,SMC=FALSE,ylabel=NULL,show.legend=TRUE,sim=TRUE,quant=.95,cor="cor",use="pairwise",plot=TRUE,correct=.5)  { 
+function(x,n.obs=NULL,fm="minres",fa="both",nfactors=1,main="Parallel Analysis Scree Plots",n.iter=20,error.bars=FALSE,se.bars=FALSE,SMC=FALSE,ylabel=NULL,show.legend=TRUE,sim=TRUE,quant=.95,cor="cor",use="pairwise",plot=TRUE,correct=.5,sqrt=FALSE)  { 
  cl <- match.call()
 # if(!require(parallel)) {message("The parallel package needs to be installed to run mclapply")}
 	
@@ -57,11 +58,12 @@ function(x,n.obs=NULL,fm="minres",fa="both",nfactors=1,main="Parallel Analysis S
  	
  	 
   				
-   valuesx  <- eigen(rx)$values #these are the PC values
+   valuesx  <- eigen(rx,only.values=TRUE)$values #these are the PC values
    if(SMC) {diag(rx) <- smc(rx)
-   fa.valuesx <- eigen(rx)$values} else {
+   fa.valuesx <- eigen(rx,only.values=TRUE)$values} else {
    fa.valuesx  <- fa(rx,nfactors=nfactors,rotate="none", fm=fm,warnings=FALSE)$values}  #these are the FA values
- 
+   if(sqrt) {valuesx <- sqrt(valuesx)
+   fa.valuesx[fa.valuesx>0] <- sqrt(fa.valuesx[fa.valuesx >0])}
   temp <- list(samp =vector("list",n.iter),samp.fa = vector("list",n.iter),sim=vector("list",n.iter),sim.fa=vector("list",n.iter))
    
 #parallel processing starts here  - the more cores the better!
@@ -79,9 +81,9 @@ function(x,n.obs=NULL,fm="minres",fa="both",nfactors=1,main="Parallel Analysis S
        cor = {C <- cor(sampledata,use=use)},
        cov = {C <- cov(sampledata,use=use) 
               covar <- TRUE},
-       tet = {C <- tetrachoric(sampledata,correct=correct)$rho},
-       poly = {C <- polychoric(sampledata,correct=correct)$rho},
-       mixed = {C <- mixedCor(sampledata,use=use,correct=correct)$rho},
+       tet = {C <- suppressWarnings(tetrachoric(sampledata,correct=correct)$rho)},
+       poly = {C <- suppressWarnings(polychoric(sampledata,correct=correct)$rho)},
+       mixed = {C <- suppressWarnings(mixedCor(sampledata,use=use,correct=correct)$rho)},
        Yuleb = {C <- YuleCor(sampledata,,bonett=TRUE)$rho},
        YuleQ = {C <- YuleCor(sampledata,1)$rho},
        YuleY = {C <- YuleCor(sampledata,.5)$rho } 
@@ -89,12 +91,12 @@ function(x,n.obs=NULL,fm="minres",fa="both",nfactors=1,main="Parallel Analysis S
 
                     bad <- any(is.na(C))   #some (not frequently) correlations will be improper, particularly if sampling from sparse matrices                 
            }  #Try resampling until we get a correlation matrix that works                    
-   					values.samp <- eigen(C)$values
+   					values.samp <- eigen(C,only.values=TRUE)$values
    					temp[["samp"]] <- values.samp
    					if (fa!= "pc") {
    					 if(SMC) {sampler <- C 
    					          diag(sampler) <- smc(sampler)
-   					 temp[["samp.fa"]]<- eigen(sampler)$values} else {
+   					 temp[["samp.fa"]]<- eigen(sampler,only.values=TRUE)$values} else {
    					 temp[["samp.fa"]]  <- fa(C,fm=fm,nfactors=nfactors, SMC=FALSE,warnings=FALSE)$values
           					}
           					}
@@ -103,11 +105,11 @@ function(x,n.obs=NULL,fm="minres",fa="both",nfactors=1,main="Parallel Analysis S
   if(sim) { simdata=matrix(rnorm(nsub*nvariables),nrow=nsub,ncol=nvariables)    #create simulated data based upon normal theory
    sim.cor <- cor(simdata)   #we must use correlations based upon Pearson here, because we are simulating the data
   
-   temp[["sim"]] <- eigen(sim.cor)$values
+   temp[["sim"]] <- eigen(sim.cor,only.values=TRUE)$values
     
    if (fa!="pc") {
         if(SMC) { diag(sim.cor) <- smc(sim.cor)
-   					 temp[["sim.fa"]]<- eigen(sim.cor)$values} else {fa.values.sim <- fa(sim.cor,fm=fm,nfactors=nfactors,rotate="none",SMC=FALSE,warnings=FALSE)$values
+   					 temp[["sim.fa"]]<- eigen(sim.cor,only.values=TRUE)$values} else {fa.values.sim <- fa(sim.cor,fm=fm,nfactors=nfactors,rotate="none",SMC=FALSE,warnings=FALSE)$values
    		 temp[["sim.fa"]]    <- fa.values.sim
 }}}
    replicates <- list(samp=temp[["samp"]],samp.fa=temp[["samp.fa"]],sim=temp[["sim"]],sim.fa=temp[["sim.fa"]])
@@ -122,10 +124,10 @@ function(x,n.obs=NULL,fm="minres",fa="both",nfactors=1,main="Parallel Analysis S
          both =  "eigenvalues of principal components and factor analysis")
     }
         
-         
+      
    values<- t(matrix(unlist(templist),ncol=n.iter))
    
-  
+    if(sqrt) {values[values >0] <- sqrt(values[values>0])}   #added 12/13/22
    values.sim.mean=colMeans(values,na.rm=TRUE)
    # if(!missing(quant)) {values.ci = apply(values,2,function(x) quantile(x,quant))} else {values.ci <- values.sim.mean} #fixed Sept 22, 2018
    values.ci = apply(values,2,function(x) quantile(x,quant)) #always apply quant
@@ -311,7 +313,7 @@ fa =  {legend("topright", c("FA  Actual Data", " FA  Simulated Data"), col = c("
    
 
 colnames(values) <- paste0("Sim",1:ncol(values))
-if(fa!= "pc" && plot) abline(h=1)
+if(fa!= "fa" && plot) abline(h=1)  #switched to fa not pc 2/27/2 
 results <- list(fa.values = fa.valuesx,pc.values=valuesx,pc.sim=sim.pc,pc.simr = sim.pcr,fa.sim=sim.fa,fa.simr = sim.far,nfact=fa.test,ncomp=pc.test, Call=cl) 
 
 
@@ -338,7 +340,7 @@ return(invisible(results))
 
 
 #a cut down plotting function
-"plot.fa.parallel" <- 
+"plot_fa.parallel" <- 
 function(x,n.obs,fa,show.legend,error.bars=FALSE,main="Parallel Analysis Scree Plots",...) {
 if(missing(n.obs)) n.obs <- NULL
 if(missing(fa)) fa <- "both"
@@ -423,7 +425,7 @@ fp[[13]] <- fa.parallel(x,quant=.95,n.obs=n.obs)
 return(fp)
 }
 
-print.psych.parallel <- function(x,digits=2) {
+print_psych.parallel <- function(x,digits=2) {
 cat("Call: ")
               print(x$Call) 
               if(!is.null(x$fa.values) & !is.null(x$pc.values) ) {
@@ -453,6 +455,22 @@ cat("Call: ")
 }
 
 
+# run fa.parallel over set of keys
+
+paSelect <- function(keys,x,cor="cor", fm="minres",plot=FALSE) {
+temp <- list()
+for (i in 1:length(keys)) {
+   select <- selectFromKeys(keys[[i]])
+   pa  <- fa.parallel(x[,select],cor=cor,fm=fm,plot=plot)
+   temp[[i]] <- list(pa$nfact,pa$ncomp)
+   }
+result <- as.data.frame(matrix(unlist(temp),ncol=2,byrow=TRUE))
+
+colnames(result) <- c("N.factors", "N.components")
+
+rownames(result) <- names(keys)
+return(result)
+}
 
 
  
\ No newline at end of file
