@@ -1,7 +1,7 @@
 #reorganized May 25, 2009 to call several print functions (psych.print.x where x = {fa, omega, stats, vss}
 #reorganized, January 18, 2009 to make some what clearer
 #added the switch capability, August 25, 2011 following suggestions by Joshua Wiley
-
+#changed from print.psych.x to print_psych.x because of change to R development not liking print.x.y format
 "print.psych" <-
 function(x,digits=2,all=FALSE,cut=NULL,sort=FALSE,short=TRUE,lower=TRUE,signif=NULL,...) { 
 #probably need to fix this with inherits but trying to avoid doing that now.
@@ -16,23 +16,23 @@ if(value =="set.cor") value <- "setCor"
 switch(value,
 
 ## the following functions have their own print function
-esem  = {print.psych.esem(x,digits=digits,short=short,cut=cut,...)},
- extension = { print.psych.fa(x,digits=digits,all=all,cut=cut,sort=sort,...)},
- extend = {print.psych.fa(x,digits=digits,all=all,cut=cut,sort=sort,...)},
- fa =  {print.psych.fa(x,digits=digits,all=all,cut=cut,sort=sort,...)},
- fa.ci = { print.psych.fa.ci(x,digits=digits,all=all,... )},
- iclust= { print.psych.iclust(x,digits=digits,all=all,cut=cut,sort=sort,...)},
- omega = { print.psych.omega(x,digits=digits,all=all,cut=cut,sort=sort,...)},
- omegaSem=  {print.psych.omegaSem(x,digits=digits,all=all,cut=cut,sort=sort,...)},
-  principal ={print.psych.fa(x,digits=digits,all=all,cut=cut,sort=sort,...)},
-  schmid = { print.psych.schmid(x,digits=digits,all=all,cut=cut,sort=sort,...)},
-  stats = { print.psych.stats(x,digits=digits,all=all,cut=cut,sort=sort,...)},
-  vss= { print.psych.vss(x,digits=digits,all=all,cut=cut,sort=sort,...)},
-  cta = {print.psych.cta(x,digits=digits,all=all,...)},
-  mediate = {print.psych.mediate(x,digits=digits,short=short,...)},
-  multilevel = {print.psych.multilevel(x,digits=digits,short=short,...)},
-  testRetest = {print.psych.testRetest(x,digits=digits,short=short,...)},
-  bestScales = {print.psych.bestScales(x,digits=digits,short=short,...)},
+esem  = {print_psych.esem(x,digits=digits,short=short,cut=cut,...)},
+ extension = { print_psych.fa(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+ extend = {print_psych.fa(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+ fa =  {print_psych.fa(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+ fa.ci = { print_psych.fa.ci(x,digits=digits,all=all,... )},
+ iclust= { print_psych.iclust(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+ omega = { print_psych.omega(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+ omegaSem=  {print_psych.omegaSem(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+  principal ={print_psych.fa(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+  schmid = { print_psych.schmid(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+  stats = { print_psych.stats(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+  vss= { print_psych.vss(x,digits=digits,all=all,cut=cut,sort=sort,...)},
+  cta = {print_psych.cta(x,digits=digits,all=all,...)},
+  mediate = {print_psych.mediate(x,digits=digits,short=short,...)},
+  multilevel = {print_psych.multilevel(x,digits=digits,short=short,...)},
+  testRetest = {print_psych.testRetest(x,digits=digits,short=short,...)},
+  bestScales = {print_psych.bestScales(x,digits=digits,short=short,...)},
 
 ##Now, for the smaller print jobs, just do it here.
 all=  {class(x) <- "list"
@@ -76,10 +76,11 @@ alpha = {
 },
 
 alpha.ci = { cat("\n   95% confidence boundaries (Feldt)\n")
+ if(is.na(x$r.bar)) {print("I am sorry, you need to specify the n.var to get confidence interals")} else {
 temp.df <- data.frame(lower=x$lower.ci, alpha= x$alpha,upper.ci =x$upper.ci)
  colnames(temp.df ) <- c("lower","alpha","upper")
  rownames(temp.df)<-""
- print(round (temp.df,digits))
+ print(round (temp.df,digits))}
 },
 
 autoR = {cat("\nAutocorrelations \n")
@@ -272,6 +273,7 @@ comorbid = {cat("Call: ")
           
    },
 
+cor2= {      print(round(x$r,digits=digits))},
 
 corCi = {#cat("Call:")
         # print(x$Call)
@@ -346,11 +348,11 @@ crossV = {if(is.null(x$mean.fit)) {
             cat("Cross Validation\n")
           cat("Call:")
             print(x$Call)
-         cat("\nValidities from raw items and from the correlation matrix\n")
+         cat("\nValidities from raw items or from the correlation matrix\n")
          cat("Number of unique predictors used = ",x$nvars,"\n")
         print(x$crossV,digits=digits)
-         cat("\nCorrelations based upon item based regressions \n")
-         lowerMat(x$item.R)
+         if(!is.null(x$item.R)) {cat("\nCorrelations based upon item based regressions \n")
+         lowerMat(x$item.R)}
           cat("\nCorrelations based upon correlation matrix based regressions\n")
          lowerMat(x$mat.R)
          } else {cat("Bootstrapped Cross Validation\n")
@@ -374,6 +376,18 @@ describe= {if(!is.null(x$signif)) {
                    if(!missing(signif)) x <- signifNum(x,digits=signif)
             print(round(x,digits=digits)) }
          },
+         
+Pdescribe= {if(!is.null(x$signif)) {
+        if( missing(signif) ) signif <-x$signif
+          x$signif <- NULL }
+         if  (length(dim(x))==1) {class(x) <- "list"
+              attr(x,"call") <- NULL
+              if(!missing(signif)) x <- signifNum(x,digits=signif)
+              print(round(x,digits=digits))
+                  } else  {class(x) <- "data.frame" 
+                   if(!missing(signif)) x <- signifNum(x,digits=signif)
+            print(round(x,digits=digits)) }
+         },
 describeBy = {cat("\n Descriptive statistics by group \n")
               if(!is.null(x$Call)){ cat("Call: " )
               print(x$Call) }
@@ -465,6 +479,28 @@ guttman =  {
             cat("\nSee the help file for a discussion of the other 4 McGraw and Wong estimates,")
    },
    
+glb = {
+cat("Call: ") 
+    print(x$Call)
+cat("\nEstimates of the Greatest Lower Bound for reliability, based on factor and cluster models")
+
+ cat("\nGLB estimated from factor based communalities = ", round(x$glb.fa$glb,digits) ,"with ",x$nf, " factors.")
+ cat("\nUse glb.fa to see more details \n")
+ 
+ cat("\n Various estimates based upon splitting the scale into two (see keys for the various splits)")
+ cat("\nBeta = ", round(x$beta,digits) , "\nBeta fa",round(x$beta.fa,digits), " This is an estimate of the worst split half reliability")  
+ cat("\nKmeans clusters for best split ",round(x$glb.Km,digits=2))
+cat("\nCluster based estimates \nglb.IC = ",round(x$glb.IC,digits))
+cat("\nglb.max ", round(x$glb.max,digits),"Is the maximum of these estimates")
+cat("\n alpha-PC = ", round(x$alpha.pc,digits),"An estimate of alpha based on eignvalues")   #\nglb.IC) = " ,round(x$glb.IC,digits)) #"\nL5 = ", round(x$lambda.5,digits), "\nL6 (smc) = " ,round(x$lambda.6,digits), "\n")
+ cat("\nTenBerge bounds \nmu0 = ",round(x$tenberge$mu0,digits), "mu1 = ", round(x$tenberge$mu1,digits), "mu2 = " ,round(x$tenberge$mu2,digits), "mu3 = ",round(x$tenberge$mu3,digits) , "\n")
+ cat("\nestimated greatest lower bound based upon splitHalf = ", round(x$glb.Fa,digits),"\n")
+
+if(!short) {cat("\n Various ways of keying the results\n")
+    x$keys} else {cat("\nUse short = FALSE to see the various ways of splitting the scale")}
+    
+},
+   
 iclust.sort = {
      nvar <- ncol(x$sort) 
      x$sort[4:nvar] <- round(x$sort[4:nvar],digits)
@@ -556,7 +592,7 @@ mixed= { cat("Call: ")
 omegaDirect ={ cat("Call: ")
         print(x$Call)
         cat("\nOmega from direct Schmid Leiman = ", round(x$omega.g,digits=digits),"\n")
-        print.psych.fa(x)
+        print_psych.fa(x)
         
        eigenvalues <- diag(t(x$loadings) %*% x$loadings)
        cat("\nWith eigenvalues of:\n")
@@ -613,7 +649,8 @@ parallel= {
 cat("Call: ")
               print(x$Call) 
               if(!is.null(x$fa.values) & !is.null(x$pc.values) ) {
-                  parallel.df <- data.frame(fa=x$fa.values,fa.sam =x$fa.simr,fa.sim=x$fa.sim,pc= x$pc.values,pc.sam =x$pc.simr,pc.sim=x$pc.sim)
+                  parallel.df <- data.frame(fa=x$fa.values,fa.sam =x$fa.simr,fa.sim=x$fa.sim,
+                  pc= x$pc.values,pc.sam =x$pc.simr,pc.sim=x$pc.sim)
 		fa.test <- x$nfact
 		pc.test <- x$ncomp
 		
@@ -789,7 +826,16 @@ reliability ={cat("Measures of reliability \n")
          
 residuals = { if(NCOL(x) == NROW(x)) {
    if (lower) {lowerMat (x,digits=digits)}} else {print(round(unclass(x),digits))}  #tweaked 1/30/18
-	},   
+	}, 
+	
+rmsea ={cat("RMSEA:  Root Mean Square Error of Approximation\n")
+       #"RMSEA=",round(x[[1]],digits=digits), "with lower bound = " ,round(x[[3]],digits=digits), "upper bound = ",round(x[[2]],digits=digits))
+     if(!is.null(x) ){cat("\nRMSEA and the ",1-x[[4]]  ,"confidence intervals are ",round(x[[1]],digits+1),round(x[[2]],digits+1),round(x[[3]],digits+1))
+       } },
+          
+RV = {cat("Correlations beween two sets\nCall: ")
+       print(x$Call)
+        cat("RV",round(x$RV,digits),  "Cohen Set Correlation",round(x$Rset,digits), "R unweighted",round(x$Ru,digits)) },
 	
 	
 scree = {
@@ -858,7 +904,7 @@ scoreBy = { cat("Call: ")
    cat("\n To see the correlations as a matrix, examine the cor.mat object ")
     },
 
-setCor= { cat("Call: ")
+lmCor= { cat("Call: ")
                           print(x$Call)
             if(x$raw) {cat("\nMultiple Regression from raw data \n")} else {
             cat("\nMultiple Regression from matrix input \n")}
@@ -1036,3 +1082,4 @@ Yule = {cat("Yule and Generalized Yule coefficients")
 }
   )   #end of switch 
 }  #end function
+
