@@ -14,8 +14,18 @@
      }   else {stop("key must have as many elements as columns of 'data' ")}
  
 if (score) {
-  if(skew) {item.stats <- describe(items,ranges=FALSE,skew=skew,fast=FALSE)[,2:7] } else {  #added the fast=FALSE on 2/25/16 in response to problem with large data sets reported by Rodrigo Travitzki 
-            item.stats <- describe(items,ranges=FALSE,skew=skew,fast=TRUE)[,2:4] }
+  if(skew) {  #item.stats <- describe(items,ranges=FALSE,skew=skew,fast=FALSE)[,2:7] 
+             #} else {  #added the fast=FALSE on 2/25/16 in response to problem with large data sets reported by Rodrigo Travitzki 
+            #item.stats <- describe(items,ranges=FALSE,skew=skew,fast=TRUE)[,2:4] }
+            #modified 2/25/24 to fix problem with qgraph 
+            item.stats <- describe(items,ranges=FALSE,skew=skew,fast=FALSE)
+            class(item.stats) <- "data.frame"
+            item.stats <- item.stats[,2:7]} else {
+            item.stats <- describe(items,ranges=FALSE,skew=skew,fast=FALSE)
+             class(item.stats) <- "data.frame"
+             item.stats <- item.stats[,2:4]}
+            
+            
             miss.rep <- rowSums(is.na(items))
     if(missing) {
         miss <- which(is.na(items),arr.ind=TRUE)
@@ -48,9 +58,13 @@ keys <- rep(1,nvar)      #now, score the items as the sum of correct
     item.stats <- cbind(key,response.freq,item.cor,item.stats)
     colnames(item.stats)[alternatives+2] <- "r"
    
-   if(short) {results <- list(item.stats=round(item.stats,digits),alpha=round(alpha.scale,digits), av.r=round(av.r,digits),Call=cl)} else 
-   if (sum(miss.rep) >0) {results <-list(scores=scores,missing = miss.rep,item.stats=round(item.stats,digits),alpha=round(alpha.scale,digits), av.r=round(av.r,digits))} else{  
-    results <- list(scores=scores,item.stats=item.stats,alpha=round(alpha.scale,digits), av.r=round(av.r,digits),Call=cl)}  
+   if(short) {results <- list(item.stats=round(item.stats,digits),alpha=round(alpha.scale,digits), av.r=round(av.r,digits),Call=cl)} else {
+   if (sum(miss.rep) > 0) {results <-list(scores=scores,missing = miss.rep,item.stats=round(item.stats,digits),
+         alpha=round(alpha.scale,digits), av.r=round(av.r,digits))} else {  
+    results <- list(scores=scores,item.stats=item.stats,alpha=round(alpha.scale,digits), av.r=round(av.r,digits),Call=cl)
+    }  
+    }
+    
 
  class(results) <- c("psych","mchoice")
  return(results) } else {return (items)}  
@@ -60,20 +74,29 @@ keys <- rep(1,nvar)      #now, score the items as the sum of correct
   #introduce a function to get cell frequencies and compensate for possible different number of response alternatives
  
 
-response.frequencies <-
+"response.frequencies" <- function(items,max=10,uniqueitems=NULL) {responseFrequency(items=items,max=max,uniqueitems=uniqueitems)}
+
+"responseFrequency" <- 
     function (items, max = 10,uniqueitems=NULL)
 {
-    min.item <- min(items, na.rm = TRUE)
-    max.item <- max(items, na.rm = TRUE)
+     min.item <- apply(items,2,function(x) min(x,na.rm=TRUE))
+     max.item <- apply(items,2,function(x) max(x,na.rm=TRUE))
+     select <- (max.item - min.item) < (max +1) 
+     items <- items[,select]
+     
    if(is.null(uniqueitems))  uniqueitems <- unique(as.vector(unlist(items)))
-    if ((max.item - min.item > max) ||
+    if ( min((max.item - min.item ) > max) ||
         (nlevels(factor(items[[ 1]])) > max) ||    #changed to [[ ]] following suggestion from Mikko Ronkko
         length(uniqueitems) > max) {
         frequency <- NULL
+       message("Number of categories should be increased  in order to count frequencies. ")
     }
     else {
-        n.var <- dim(items)[2]
-        n.cases <- dim(items)[1]
+       #just describe those items that have less than max categories
+       
+        n.var <- NCOL(items)              #changed to handle case of single variable 
+        n.cases <- NROW(items)
+        if(n.var < 2 ) message("Number of categories should be increased  in order to count frequencies. ")
         dummy <- matrix(rep(uniqueitems, n.var), ncol = n.var)
         colnames(dummy) <- names(items)
         xdum <- rbind(items, dummy)
@@ -83,7 +106,9 @@ response.frequencies <-
         frequency <- frequency/responses
         miss <- 1 - responses/n.cases
         frequency <- cbind(frequency, miss)
+       # class(frequency) <- cs(psych,frequency)
     }
+   
     return(frequency)
 }
 	
@@ -91,4 +116,5 @@ response.frequencies <-
  #revised Sept 3, 2010 to count missing responses
  #revised Sept 7, 2010 to correctly handle missing data in terms of finding alpha and correlation
  #revised April 3, 2011 to incorporate very nice suggestion by Joshua Wiley to handle unique categories
- #revised August 4, 2012 to allow the specification of unique items-- useful for irt.responses
\ No newline at end of file
+ #revised August 4, 2012 to allow the specification of unique items-- useful for irt.responses
+ #revised July 8, 2020 to use psych print function and added the camel case version. Also to process  just those items that have  <= max responses
\ No newline at end of file
