@@ -12,7 +12,7 @@ function(object,digits=2,items=FALSE,...) {
 
 if(length(class(object)) > 1)  { 
 mat.reg <- bassAck <- overlap <-  scores <- none <- extend <- extension <- crossV <- NA    #to let it compile in R4.0
- obnames <- cs(principal,score.items,cluster.loadings,mat.regress, set.cor, mat.reg, bassAck, bestScales,crossV,iclust,omega,omegaSem,omegaDirect,overlap,
+ obnames <- cs(principal,score.items,cluster.loadings,mat.regress, set.cor, lmCor, mat.reg, bassAck, bestScales,crossV,iclust,omega,omegaSem,omegaDirect,overlap,
      scores,testRetest, vss,cluster.cor, esem,fa,faBy,extend,extension,items,alpha,setCor,irt.fa,cohen.d,cohen.d.by,mediate,describeData,none)
      value <- inherits(object, obnames, which=TRUE)
 			   if (any(value > 1)) {value <- obnames[which(value >0)]} else {value <- "none"}
@@ -23,8 +23,8 @@ mat.reg <- bassAck <- overlap <-  scores <- none <- extend <- extension <- cross
  if(value=="score.items") value <- "scores"
  if(value=="cluster.loadings") value <- "cluster.cor"
   if(value=="mat.regress") value <- "mat.reg"
-   if(value=="set.cor") value <- "setCor"
-    if(value=="mat.reg") value <- "setCor"
+   if(value=="set.cor") value <- "lmCor"
+    if(value=="mat.reg") value <- "lmCor"
  } else {value <- "none"}
  
 switch(value, 
@@ -63,7 +63,7 @@ bestScales = { cat("\nCall = ")
             print(object$Call)
          cat("\nValidities from raw items and from the correlation matrix\n")
          cat("Number of unique predictors used = ",object$nvars,"\n")
-        print(object$crossV,digits=digits)
+        if(!is.null(object$mean.fit)) {print(object$mean.fit,digits=digits)} else  {print(object$crossV,digits=digits)}
  },
  
  
@@ -336,7 +336,7 @@ cat("\nReliability analysis ",object$title," \n")
 print(object$total,digits=digits)
 },
  
-setCor = {
+lmCor = {
    if(object$raw) {cat("\nMultiple Regression from raw data \n")} else {
             cat("\nMultiple Regression from matrix input \n")}
 
@@ -401,7 +401,7 @@ rownames(effect.df) <- names(object)
 print(effect.df,digits=digits)
     }, 
 
-mediate = {summary.psych.mediate(object,digits=digits)
+mediate = {summary_psych.mediate(object,digits=digits)
         },
 
 describeData = {   cat('n.obs = ', object$n.obs, "of which ", object$complete.cases," are complete cases. Number of variables = ",object$nvar," of which all are numeric is ",object$all.numeric,"\n")},
@@ -446,3 +446,5 @@ none = {warning("I am sorry, I do not have a summary function for this object")}
 #invisible(result)
    }
   
+
+#
